@@ -9,9 +9,11 @@ import re
 
 from .base import ExportersTestsBase
 from ..latex import LatexExporter
+from ...tests.utils import onlyif_cmds_exist
+
+from traitlets.config import Config
 from nbformat import write
 from nbformat import v4
-from ipython_genutils.testing.decorators import onlyif_cmds_exist
 from testpath.tempdir import TemporaryDirectory
 
 from jinja2 import DictLoader
@@ -117,6 +119,22 @@ class TestLatexExporter(ExportersTestsBase):
         assert re.findall(in_regex, output) == ins
         assert re.findall(out_regex, output) == outs
 
+    @onlyif_cmds_exist('pandoc')
+    def test_no_prompt_yes_input(self):
+        no_prompt = {
+            "TemplateExporter":{
+                "exclude_input_prompt": True,
+                "exclude_output_prompt": True,
+            }
+        }
+        c_no_prompt = Config(no_prompt)
+
+        exporter = LatexExporter(config=c_no_prompt)
+        (output, resources) = exporter.from_filename(
+            self._get_notebook(nb_name="prompt_numbers.ipynb"))
+        assert "shape" in output
+        assert "evs" in output
+        
     def test_in_memory_template_tplx(self):
         # Loads in an in memory latex template (.tplx) using jinja2.DictLoader
         # creates a class that uses this template with the template_file argument
@@ -129,3 +147,17 @@ class TestLatexExporter(ExportersTestsBase):
         exporter = MyExporter(extra_loaders=[my_loader_tplx])
         nb = v4.new_notebook()
         out, resources = exporter.from_notebook_node(nb)
+
+    def test_custom_filter_highlight_code(self):
+        # Overwriting filters takes place at: Exporter.from_notebook_node
+        nb = v4.new_notebook()
+        nb.cells.append(v4.new_code_cell("some_text"))
+
+        def custom_highlight_code(source, language="python", metadata=None, strip_verbatim=False):
+            return source + " ADDED_TEXT"
+
+        filters = {
+            "highlight_code": custom_highlight_code
+        }
+        (output, resources) = LatexExporter(filters=filters).from_notebook_node(nb)
+        self.assertTrue("ADDED_TEXT" in output)
